==> worlds_sims4-1.7.1.tar.gz: worlds_sims4-1.7.1/src/worlds/sims4/docs/setup_en.md <==
# The Sims 4 Randomizer Setup Guide

## Required Software
- [MultiworldGG](https://github.com/MultiworldGG/MultiworldGG/releases/latest)
- [The Sims 4](https://store.steampowered.com/app/1222670/The_Sims_4/)
- [sims4.apworld](https://github.com/meaomeaomeaoo/Archipelago/releases) (not needed for MWGG)
- [The .ts4script and the .package files](https://github.com/meaomeaomeaoo/Sims4ArchipelagoMod/releases)
- [The mod files from Sims 4 community library](https://github.com/ColonolNutty/Sims4CommunityLibrary/releases)

## Instillation
- Install MultiworldGG
- Add sims4.apworld to custom_worlds folder in your MultiworldGG directory or double click the .apworld to install it automatically (not needed for MWGG)
- Follow MultiworldGG's tutorial on [how to generate a game.](https://multiworld.gg/tutorial/Archipelago/setup/en)
- Make sure you download both the .ts4script and .package files from Sims 4 community library and the sims 4 archipelago mod and install them to your mods folder (usually located in Documents/Electronic Arts/The Sims 4/Mods)

## Setting up
- This mod only uses skills from the base game as checks and locations. Make sure to disable your packs as they are likely to break the mod. 
  * If you dont know how to do so you can use this [tutorial](https://jamesturner.yt/disablepacks) by James Turner
- Open the MultiworldGG launcher and run The Sims 4 client and connect to the server.
- Start The Sims 4 and make a new save
  * Make sure to enable script mods under game options -> Other -> Script Mods Allowed (The mod will not work without it)
  * You can use an existing save but its better to use a new save as this mod will reset your sims' skills on connect

==> worlds_sims4-1.7.5.tar.gz: worlds_sims4-1.7.5/src/worlds/sims4/docs/setup_en.md <==
# The Sims 4 Randomizer Setup Guide

## Required Software
- [Archipelago](https://github.com/ArchipelagoMW/Archipelago/releases/latest)
- [The Sims 4](https://store.steampowered.com/app/1222670/The_Sims_4/)
- [sims4.apworld](https://github.com/Simsipelago/Archipelago/releases/latest)
- [The .ts4script and the .package files](https://github.com/Simsipelago/Sims4ArchipelagoMod/releases/latest)
- [The mod files from Sims 4 community library](https://github.com/ColonolNutty/Sims4CommunityLibrary/releases)

## Instillation
- Install MultiworldGG
- Add sims4.apworld to custom_worlds folder in your MultiworldGG directory or double click the .apworld to install it automatically (not needed for MWGG)
- Follow MultiworldGG's tutorial on [how to generate a game.](https://multiworld.gg/tutorial/Archipelago/setup/en)
- Make sure you download both the .ts4script and .package files from Sims 4 community library and the sims 4 archipelago mod and install them to your mods folder (usually located in Documents/Electronic Arts/The Sims 4/Mods)

## Setting up
- This mod only uses skills from the base game as checks and locations. Make sure to disable your packs as they are likely to break the mod. 
  * If you dont know how to do so you can use this [tutorial](https://jamesturner.yt/disablepacks) by James Turner
- Open the MultiworldGG launcher and run The Sims 4 client and connect to the server.
- Start The Sims 4 and make a new save
  * Make sure to enable script mods under game options -> Other -> Script Mods Allowed (The mod will not work without it)
  * You can use an existing save but its better to use a new save as this mod will reset your sims' skills on connect
